@@ -1,11 +1,11 @@
 #![warn(missing_docs)]
-//! Parser and renderer for the TinyVG vector graphics format
+//! Decoder and renderer for the TinyVG vector graphics format
 
+pub mod decode;
 pub mod format;
-pub mod parser;
 mod render;
 
 pub mod render_helper;
 
+pub use decode::Decoder;
 pub use format::Image;
-pub use parser::Parser;
